;#############################################################################
;---------------- DEFINE DEVICE SERIAL NUMBERS TO USE ------------------------
;#############################################################################

; Get a handle for the device with the given serial number
; To determine serial number of device: Press "MENU" -> Select "Version Info"
; This handle must be used in the script for every function call 
; to exactly specify the device where the command should be send to

; Add more devices, if needed

Global $Device1 = OpenPeconDevice("140-08-0010")
; Global $Device2 = OpenPeconDevice("141-11-pt01")
; Global $Device3 = OpenPeconDevice("140-11-0001")



;#############################################################################
;--------------------- BEGIN USER CHANGEABLE PART ----------------------------
;#############################################################################
; Commands for the device should be placed in here
; See "PDL2000_AutoIt3-Functions.au3 for command definition
; Use $Device1, $Device2, etc. as handle for commands, definition is in "PDL2000_Core-Script.au3"
; Read AutoIt3 documentation (http://www.autoitscript.com) and have fun!

;-----------------------------------------------------------------------------

; Example8: How to set up a simple GUI
; To learn more see Example "SampleControls.au3" in AutoIt3 folder
; Use Koda FormDesigner (http://koda.darkhost.ru) for easy GUI design
; 
; Combine it with Record Example5 to get a DataLogger with GUI
; and use "FileOpenDialog" to set the filename from GUI

#include <ButtonConstants.au3>
#include <EditConstants.au3>
#include <GUIConstantsEx.au3>
#include <StaticConstants.au3>
#include <WindowsConstants.au3>

;Define some variables
local $DeviceSerial1 = "141-11-pt01"
local $MaxAllowedTempDev = 0.5 ; Define allowed +/- temperature range for changing temperature display from red to green
local $LoopControl1 = GetLoopControl 		($Device1, 1)



; Setup GUI (code from Koda designer)
#Region ### START Koda GUI section ### Form=
$Form1_1 = GUICreate("GUI Test", 242, 172, -1, -1)
$lbl_Device = GUICtrlCreateLabel("Device:", 16, 8, 215, 24)
GUICtrlSetFont(-1, 12, 800, 0, "MS Sans Serif")
$prg_Timer = GUICtrlCreateProgress(128, 136, 97, 10)
$grp_Channel = GUICtrlCreateGroup("Channel 1:", 16, 32, 209, 97)
$lbl_ActualValue = GUICtrlCreateLabel("--.-", 24, 56, 114, 63)
GUICtrlSetFont(-1, 36, 400, 0, "Verdana")
$inp_SetpointValue = GUICtrlCreateInput("--.-", 160, 56, 57, 26)
GUICtrlSetFont(-1, 12, 400, 0, "Verdana")
$btn_LoopCon = GUICtrlCreateButton("---", 160, 96, 57, 25, $WS_GROUP)
GUICtrlCreateGroup("", -99, -99, 1, 1)
$lbl_DLLVersion = GUICtrlCreateLabel("DLL-Version:", 16, 155, 217, 17)
GUICtrlSetFont(-1, 6, 400, 0, "Verdana")
$lbl_Timer = GUICtrlCreateLabel("Next GUI update cycle", 16, 136, 114, 17)
GUISetState(@SW_SHOW)
#EndRegion ### END Koda GUI section ###

; Show PDL200.dll Version on GUI
$DllVersion = 		GetDllVersion ()
GUICtrlSetData($lbl_DLLVersion, 	"DLL-Version: V" & $DLLVersion)

; Show device serial on GUI
GUICtrlSetData($lbl_Device, 	"Device: " & $DeviceSerial1)

; Show component name on GUI
$ComponentName1 = 	GetComponentName 	($Device1, 1)
GUICtrlSetData($grp_Channel, 		"Channel 1: " & $ComponentName1)

; Initialize a timer for cycle request to device
$Timer = TimerInit()
; Set cycle time im ms for device data updates
$CycleTime = 10000 

; Main cycle: Update GUI values and wait for clicks on GUI and react accordingly
While 1
	
	; Update progress bar
	GUICtrlSetData($prg_Timer, Round((TimerDiff($Timer) / $CycleTime)*100))
	
	; Update GUI only when cycle time has reached
	; This implementation needs 1 cycle until the first values are shown on the GUI
	; Can be solved by using the commands below once BEFORE the main cycle starts, for example
	If TimerDiff($Timer) > $CycleTime Then
		; Reset timer
		$Timer = TimerInit()
	
		; Get data from device
		$SetpointValue1 = 	GetSetpointValue   	($Device1, 1)

		$LoopControl1 = 	GetLoopControl 		($Device1, 1)

		$ActualValue1 = 	GetActualValue   	($Device1, 1)
		If $ActualValue1 = 409.6 Then 
			$ActualValue1 = "--.-"
			GUICtrlSetColor($lbl_ActualValue, 0x000000)
		EndIf

		; Fill GUI with current device data
		; The setpoint value is also overwritten
		; This might interfer with user input, especially with lower cycle times
		; To make this example easy to understand there is no solution implemented
		; A solution can be to define another setpoint variable and change value on GUI
		; only when the new setpoint from device differs from the old setpoint
		GUICtrlSetData($lbl_ActualValue, 	FormatDecimalValue($ActualValue1))
			; Change actual temperature color in GUI according to defined deviation range
			If Abs($SetpointValue1 - $ActualValue1) > $MaxAllowedTempDev Then
				GUICtrlSetColor($lbl_ActualValue, 0xFF0000)
			Else
				GUICtrlSetColor($lbl_ActualValue, 0x007F00)
			EndIf

		GUICtrlSetData($inp_SetpointValue, 	FormatDecimalValue(	$SetpointValue1))
		
		If $LoopControl1 = 1 Then
			GUICtrlSetData($btn_LoopCon, "On")
		ElseIf $LoopControl1 = 0 Then
			GUICtrlSetData($btn_LoopCon, "Off")
		EndIf
		
	EndIf
	 	
	; React on GUI clicks
	$nMsg = GUIGetMsg()
	Switch $nMsg
		; Click on the red "X"
		; Exit program
		Case $GUI_EVENT_CLOSE
			Exit

		; Change of setpoint value
		; Send new value to device and update GUI to reflect min/max exceeding
		Case $inp_SetpointValue
			SetSetpointValue	($Device1, 1, GUICtrlRead($inp_SetpointValue))	
			$SetpointValue1 = 	GetSetpointValue   	($Device1, 1)
			GUICtrlSetData($inp_SetpointValue, 	FormatDecimalValue(	$SetpointValue1))


		; Click on LoopControl button
		; Toggle loop control state, send command to device und update GUI
		Case $btn_LoopCon
			If $LoopControl1 = 1 Then
				$LoopControl1 = 0
			ElseIf $LoopControl1 = 0 Then
				$LoopControl1 = 1
			EndIf
				
			SetLoopControl ($Device1, 1, $LoopControl1)
			
			If $LoopControl1 = 1 Then
				GUICtrlSetData($btn_LoopCon, "On")
			ElseIf $LoopControl1 = 0 Then
				GUICtrlSetData($btn_LoopCon, "Off")
			EndIf

			
	EndSwitch

WEnd